@@ -5,7 +5,7 @@ from adam.commands.check import Check, CheckCommandHelper
 from adam.commands.cp import ClipboardCopy, CopyCommandHelper
 from adam.commands.command import Command
 from adam.commands.command_helpers import ClusterCommandHelper, ClusterOrPodCommandHelper, PodCommandHelper
-from adam.commands.cqlsh import CqlCommandHelper, Cqlsh
+from adam.commands.cql.cqlsh import CqlCommandHelper, Cqlsh
 from adam.commands.deploy.deploy import Deploy, DeployCommandHelper
 from adam.commands.deploy.undeploy import Undeploy, UndeployCommandHelper
 from adam.commands.describe.describe import Describe, DescribeCommandHelper
