@@ -49,4 +49,4 @@ class MedusaShowBackupJobs(Command):
         return {}
 
     def help(self, _: ReplState):
-        return f'{MedusaShowBackupJobs.COMMAND}\t show backups'
\ No newline at end of file
+        return f'{MedusaShowBackupJobs.COMMAND}\t show Medusa backups'
\ No newline at end of file
