@@ -49,4 +49,4 @@ class MedusaShowRestoreJobs(Command):
         return {}
 
     def help(self, _: ReplState):
-        return f'{MedusaShowRestoreJobs.COMMAND}\t show restores'
\ No newline at end of file
+        return f'{MedusaShowRestoreJobs.COMMAND}\t show Medusa restores'
\ No newline at end of file
