@@ -1,7 +1,6 @@
 import click
 
 from adam.commands.command import Command
-from adam.commands.command_helpers import ClusterCommandHelper
 from .reaper_forward import ReaperForward
 from .reaper_forward_stop import ReaperForwardStop
 from .reaper_restart import ReaperRestart
@@ -14,7 +13,6 @@ from .reaper_schedule_stop import ReaperScheduleStop
 from .reaper_schedules import ReaperSchedules
 from .reaper_status import ReaperStatus
 from adam.repl_state import ReplState, RequiredState
-from adam.utils import lines_to_tabular, log, log2
 
 class Reaper(Command):
     COMMAND = 'reaper'
@@ -39,24 +37,12 @@ class Reaper(Command):
         if not(args := self.args(cmd)):
             return super().run(cmd, state)
 
-        state, args = self.apply_state(args, state)
-        if not self.validate_state(state):
-            return state
-
-        if state.in_repl:
-            log(lines_to_tabular([c.help(ReplState()) for c in Reaper.cmd_list()], separator='\t'))
-
-            return 'command-missing'
-        else:
-            # head with the Chain of Responsibility pattern
-            cmds = Command.chain(Reaper.cmd_list())
-            if not cmds.run(cmd, state):
-                log2('* Command is missing.')
-                Command.display_help()
+        return super().intermediate_run(cmd, state, args, Reaper.cmd_list())
 
     def cmd_list():
         return [ReaperSchedules(), ReaperScheduleStop(), ReaperScheduleActivate(), ReaperScheduleStart(),
-                ReaperForwardStop(), ReaperForward(), ReaperRunAbort(), ReaperRunsAbort(), ReaperRestart(), ReaperRuns(), ReaperStatus()]
+                ReaperForwardStop(), ReaperForward(), ReaperRunAbort(), ReaperRunsAbort(), ReaperRestart(),
+                ReaperRuns(), ReaperStatus()]
 
     def completion(self, state: ReplState):
         if state.sts:
@@ -64,15 +50,6 @@ class Reaper(Command):
 
         return {}
 
-    def help(self, _: ReplState):
-        return None
-
 class ReaperCommandHelper(click.Command):
     def get_help(self, ctx: click.Context):
-        log(super().get_help(ctx))
-        log()
-        log('Sub-Commands:')
-
-        log(lines_to_tabular([c.help(ReplState()).replace(f'{Reaper.COMMAND} ', '  ', 1) for c in Reaper.cmd_list()], separator='\t'))
-        log()
-        ClusterCommandHelper.cluster_help()
\ No newline at end of file
+        Command.intermediate_help(super().get_help(ctx), Reaper.COMMAND, Reaper.cmd_list(), show_cluster_help=True)
\ No newline at end of file
