@@ -149,7 +149,7 @@ class ReaperSession:
             return ReaperSession.schedules_ids_by_cluster[state.sts]
 
         if reaper := ReaperSession.create(state):
-            Config().wait_log("Inspecting Cassandra Reaper...")
+            Config().wait_log('Inspecting Cassandra Reaper...')
 
             schedules = reaper.schedule_ids(state, show_output = False)
             ReaperSession.schedules_ids_by_cluster[state.sts] = schedules
